@@ -5,6 +5,8 @@
 #include <orbit/orb-core/corba-any-type.h>
 #include <orbit/orb-core/orbit-object.h>
 
+G_BEGIN_DECLS
+
 #define CORBA_tk_recursive -1
 #define CORBA_tk_last (CORBA_tk_abstract_interface + 1)
 
@@ -21,7 +23,7 @@ struct CORBA_TypeCode_struct {
 	char                *name;
 	char                *repo_id;
 	char               **subnames;      /* for struct, exception, union, enum */
-	CORBA_any           *sublabels;     /* for union */
+	CORBA_long          *sublabels;     /* for union */
 	CORBA_long           default_index; /* for union */
 	CORBA_unsigned_long  recurse_depth; /* for recursive sequence */
 	CORBA_unsigned_short digits;        /* for fixed */
@@ -85,4 +87,6 @@ const char *ORBit_tk_to_name            (CORBA_unsigned_long tk);
 
 #endif /*  ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif
