@@ -139,6 +139,7 @@ ORBit_setup_debug_flags (void)
 		{ "messages", ORBIT_DEBUG_MESSAGES },
 		{ "objects",  ORBIT_DEBUG_OBJECTS },
 		{ "giop",     ORBIT_DEBUG_GIOP },
+		{ "refs",     ORBIT_DEBUG_REFS },
 	};
 	const char *env_string;
 
@@ -434,9 +435,8 @@ CORBA_ORB_list_initial_services (CORBA_ORB          orb,
 
 		retval->_release = CORBA_TRUE;
 
-		g_assert (info->index = retval->_length);
-	}
-	else {
+		g_assert (info->index == retval->_length);
+	} else {
 		retval->_length = 0;
 		retval->_buffer = NULL;
 	}
