@@ -1,14 +1,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <orb/orbit.h>
 #include "test-any.h"
 
 TestAny client;
 
 static CORBA_any *
 do_print(PortableServer_Servant servant,
-	 CORBA_any *any,
+	 const CORBA_any *any,
 	 CORBA_Environment *ev);
 
 PortableServer_ServantBase__epv base_epv = {
@@ -24,7 +23,7 @@ POA_TestAny poa_TestAny_servant = { NULL, &poa_TestAny_vepv };
 int
 main (int argc, char *argv[])
 {
-    PortableServer_ObjectId objid = {0, sizeof("myTestAny"), "myTestAny"};
+    PortableServer_ObjectId *objid;
     PortableServer_POA poa;
 
     CORBA_Environment ev;
@@ -38,8 +37,8 @@ main (int argc, char *argv[])
 
     poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
     PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(poa, &ev), &ev);
-    PortableServer_POA_activate_object_with_id(poa,
-					       &objid, &poa_TestAny_servant, 
+    objid = PortableServer_POA_activate_object(poa,
+					       &poa_TestAny_servant, 
 					       &ev);
 
     client = PortableServer_POA_servant_to_reference(poa,
@@ -63,7 +62,7 @@ main (int argc, char *argv[])
 
 static CORBA_any*
 do_print(PortableServer_Servant servant,
-	 CORBA_any *any,
+	 const CORBA_any *any,
 	 CORBA_Environment *ev)
 {
   TestAnyStruct* any_struct = any->_value; 
